simplify.domain.DomainFactory

Package simplify :: Module domain :: Class DomainFactory |
[hide private]
[frames] | no frames]

# Class DomainFactory

source code

    object --+
             |
            DomainFactory

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods | [hide private]
factory(cls, module_name, values=None, fail_on_error=False) | source code

Class Variables | [hide private]
| cache = ``{``}``

Properties | [hide private]
Inherited from `object`: `__class__`